==> mlview-0.6.1.tar.gz: mlview-0.6.1/src/mlview-app-context.h <==
/* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 8-*- */

/*This file is part of GNU MlView
 *
 *GNU MlView is free software; 
 *you can redistribute it and/or modify it under the terms of 
 *the GNU General Public License as published by 
 *the Free Software Foundation; either version 2, 
 *or (at your option) any later version.
 *
 *GNU MlView is distributed in the hope that it will be useful, 
 *but WITHOUT ANY WARRANTY; 
 *without even the implied warranty of 
 *MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *See the GNU General Public License for more details.
 *
 *You should have received a copy of the GNU General 
 *Public License along with MlView; 
 *see the file COPYING. If not, write to the 
 *Free Software Foundation, Inc., 59 
 *Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *See COPYRIGHT file for copyright informations.
 */

#ifndef __MLVIEW_APP_CONTEXT_H__
#define __MLVIEW_APP_CONTEXT_H__

#include <libxml/parser.h>
#include <libxml/catalog.h>
#include <glib.h>
#include <glib-object.h>
#include <gconf/gconf-client.h>
#include "mlview-file-selection.h"


/**
 *@file
 *#MlViewAppContext class declaration file.
 */
G_BEGIN_DECLS
#define MLVIEW_TYPE_APP_CONTEXT (mlview_app_context_get_type())
#define MLVIEW_APP_CONTEXT(object) (G_TYPE_CHECK_INSTANCE_CAST((object), MLVIEW_TYPE_APP_CONTEXT, MlViewAppContext))
#define MLVIEW_APP_CONTEXT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST((klass), MLVIEW_TYPE_APP_CONTEXT, MlViewContextClass))
#define MLVIEW_IS_APP_CONTEXT(object) (G_TYPE_CHECK_INSTANCE_TYPE((object), MLVIEW_TYPE_APP_CONTEXT))
#define MLVIEW_IS_APP_CONTEXT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass), MLVIEW_TYPE_APP_CONTEXT))
typedef struct _MlViewAppContext MlViewAppContext;
typedef struct _MlViewAppContextClass MlViewAppContextClass;
typedef struct _MlViewAppContextPrivate MlViewAppContextPrivate;

/**
 *MlViewAppContext objects structure.
 *This structure describes the data members
 *of each instance of MlViewAppContext.
 */
struct _MlViewAppContext {
        /**
	 *The member stucture of
         *MlViewAppContext's parent class.
         */
        GObject object;

        /**
         *The private members of MlViewAppContext.
         */
        MlViewAppContextPrivate *private;
};

/**
 *MlViewAppContext class structure.
 *The class inherits GObjects.
 */
struct _MlViewAppContextClass {
        /**
         *The class structure of the parent
         *class of MlViewAppContext.
         */
        GObjectClass parent_class;
};

/**
 *The public application wide settings
 *data structure.
 *This data structure is readonly the
 *applicatoin.
 */
struct MlViewAppSettings {
        gint default_doc_expansion_depth ;
        gboolean validation_is_on ;
} ;


/*************************************
 *Public API of the MlViewAppContext
 *************************************/

guint mlview_app_context_get_type (void);

gint *mlview_app_context_get_last_id_ptr (MlViewAppContext *
                                          a_this);

gint mlview_app_context_get_last_id (MlViewAppContext *
                                a_this);

void mlview_app_context_set_last_id (MlViewAppContext * a_this,
                                 gint a_new_id);

void mlview_app_context_set_element (MlViewAppContext * a_context,
                                 const gchar * a_element_name,
                                 gpointer a_context_element);

gpointer mlview_app_context_get_element (MlViewAppContext * a_context,
                                const gchar * a_element_name);

MlViewAppContext *mlview_app_context_get_instance (void);

/*display a message in the app bar*/
void mlview_app_context_sbar_push_message (MlViewAppContext * a_context,
                                           const gchar * a_msg_format, ...);

void mlview_app_context_sbar_pop_message (MlViewAppContext * a_context);

void mlview_app_context_sbar_set_default_message (MlViewAppContext * a_context,
                                                  const gchar * a_msg_format, ...);

void mlview_app_context_message (MlViewAppContext * a_context,
                                 const gchar * a_msg_format, ...);

void mlview_app_context_error (MlViewAppContext * a_context,
                               const gchar * a_msg_format, ...);

void mlview_app_context_warning (MlViewAppContext * a_context,
                                 const gchar * a_msg_format, ...);

void mlview_app_context_bufferize_error (MlViewAppContext *a_context, 
                                         const gchar *a_msg_format, ...);

void mlview_app_context_display_buffered_error (MlViewAppContext * a_context);

gboolean mlview_app_context_error_buffer_is_empty (MlViewAppContext *
                                                   a_context);

void mlview_app_context_set_error_dialog_title (MlViewAppContext * a_context,
                                                const gchar * a_title);

gchar *mlview_app_context_get_error_dialog_title (MlViewAppContext * a_context);

GConfClient * mlview_app_context_get_gconf_client (MlViewAppContext *a_this) ;

struct MlViewAppSettings * mlview_app_context_get_settings (MlViewAppContext *a_this) ;


MlViewFileSelection * mlview_app_context_get_file_selector (MlViewAppContext * a_this,
                                                            const gchar * a_title);

void mlview_app_context_set_window_icon (MlViewAppContext * a_this,
                                         GtkWindow * a_widget);

void mlview_app_context_set_window_transient_for_app (MlViewAppContext * a_this,
                                                      GtkWindow * a_window);

gint mlview_app_context_get_xpm (MlViewAppContext * a_this,
                                 const gchar * a_xpm_name,
                                 GdkPixmap ** a_pixmap,
                                 GdkBitmap ** a_bitmap);

void mlview_app_context_set_xml_catalog (MlViewAppContext * a_this,
                                         xmlCatalog * a_xml_catalog);

xmlCatalog *mlview_app_context_get_xml_catalog (MlViewAppContext* a_this);

G_END_DECLS
#endif /*__MLVIEW-APP-CONTEXT_H__*/

==> mlview-0.6.2.tar.gz: mlview-0.6.2/src/mlview-app-context.h <==
/* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 8-*- */

/*This file is part of GNU MlView
 *
 *GNU MlView is free software; 
 *you can redistribute it and/or modify it under the terms of 
 *the GNU General Public License as published by 
 *the Free Software Foundation; either version 2, 
 *or (at your option) any later version.
 *
 *GNU MlView is distributed in the hope that it will be useful, 
 *but WITHOUT ANY WARRANTY; 
 *without even the implied warranty of 
 *MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *See the GNU General Public License for more details.
 *
 *You should have received a copy of the GNU General 
 *Public License along with MlView; 
 *see the file COPYING. If not, write to the 
 *Free Software Foundation, Inc., 59 
 *Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *See COPYRIGHT file for copyright informations.
 */

#ifndef __MLVIEW_APP_CONTEXT_H__
#define __MLVIEW_APP_CONTEXT_H__

#include <libxml/parser.h>
#include <libxml/catalog.h>
#include <glib.h>
#include <glib-object.h>
#include <gconf/gconf-client.h>
#include "mlview-file-selection.h"


/**
 *@file
 *#MlViewAppContext class declaration file.
 */
G_BEGIN_DECLS
#define MLVIEW_TYPE_APP_CONTEXT (mlview_app_context_get_type())
#define MLVIEW_APP_CONTEXT(object) (G_TYPE_CHECK_INSTANCE_CAST((object), MLVIEW_TYPE_APP_CONTEXT, MlViewAppContext))
#define MLVIEW_APP_CONTEXT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST((klass), MLVIEW_TYPE_APP_CONTEXT, MlViewContextClass))
#define MLVIEW_IS_APP_CONTEXT(object) (G_TYPE_CHECK_INSTANCE_TYPE((object), MLVIEW_TYPE_APP_CONTEXT))
#define MLVIEW_IS_APP_CONTEXT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass), MLVIEW_TYPE_APP_CONTEXT))
typedef struct _MlViewAppContext MlViewAppContext;
typedef struct _MlViewAppContextClass MlViewAppContextClass;
typedef struct _MlViewAppContextPrivate MlViewAppContextPrivate;

/**
 *MlViewAppContext objects structure.
 *This structure describes the data members
 *of each instance of MlViewAppContext.
 */
struct _MlViewAppContext {
        /**
	 *The member stucture of
         *MlViewAppContext's parent class.
         */
        GObject object;

        /**
         *The private members of MlViewAppContext.
         */
        MlViewAppContextPrivate *private;
};

/**
 *MlViewAppContext class structure.
 *The class inherits GObjects.
 */
struct _MlViewAppContextClass {
        /**
         *The class structure of the parent
         *class of MlViewAppContext.
         */
        GObjectClass parent_class;
};


enum MlViewTreeEditorsNodeColour {
        MLVIEW_XML_ELEMENT_NODE_COLOUR = 0,
        MLVIEW_XML_ATTR_VAL_COLOUR,
        MLVIEW_XML_TEXT_NODE_COLOUR,
        MLVIEW_XML_COMMENT_NODE_COLOUR,
        MLVIEW_XML_DOCUMENT_NODE_COLOUR,
        MLVIEW_XML_PI_NODE_COLOUR,
        MLVIEW_XML_DTD_NODE_COLOUR,
        MLVIEW_XML_ENTITY_DECL_NODE_COLOUR,
        NB_OF_TREE_NODE_COLOURS /*this must remain the last entry of the enum*/
} ;

/**
 *The public application wide settings
 *data structure.
 *This data structure is readonly for the
 *application (so far).
 */
struct MlViewAppSettings {
        struct {
                gboolean validation_is_on ;
        } general ;
        struct {
                gint default_doc_expansion_depth ;
                gchar * nodes_colours[NB_OF_TREE_NODE_COLOURS] ;
        } tree_editors ;
        struct {
                /*reserved for futur usage.*/
        } network;
} ;


/*************************************
 *Public API of the MlViewAppContext
 *************************************/

guint mlview_app_context_get_type (void);

gint *mlview_app_context_get_last_id_ptr (MlViewAppContext *
                                          a_this);

gint mlview_app_context_get_last_id (MlViewAppContext *
                                a_this);

void mlview_app_context_set_last_id (MlViewAppContext * a_this,
                                 gint a_new_id);

void mlview_app_context_set_element (MlViewAppContext * a_context,
                                 const gchar * a_element_name,
                                 gpointer a_context_element);

gpointer mlview_app_context_get_element (MlViewAppContext * a_context,
                                const gchar * a_element_name);

MlViewAppContext *mlview_app_context_get_instance (void);

/*display a message in the app bar*/
void mlview_app_context_sbar_push_message (MlViewAppContext * a_context,
                                           const gchar * a_msg_format, ...);

void mlview_app_context_sbar_pop_message (MlViewAppContext * a_context);

void mlview_app_context_sbar_set_default_message (MlViewAppContext * a_context,
                                                  const gchar * a_msg_format, ...);

void mlview_app_context_message (MlViewAppContext * a_context,
                                 const gchar * a_msg_format, ...);

void mlview_app_context_error (MlViewAppContext * a_context,
                               const gchar * a_msg_format, ...);

void mlview_app_context_warning (MlViewAppContext * a_context,
                                 const gchar * a_msg_format, ...);

void mlview_app_context_bufferize_error (MlViewAppContext *a_context, 
                                         const gchar *a_msg_format, ...);

void mlview_app_context_display_buffered_error (MlViewAppContext * a_context);

gboolean mlview_app_context_error_buffer_is_empty (MlViewAppContext *
                                                   a_context);

void mlview_app_context_set_error_dialog_title (MlViewAppContext * a_context,
                                                const gchar * a_title);

gchar *mlview_app_context_get_error_dialog_title (MlViewAppContext * a_context);

GConfClient * mlview_app_context_get_gconf_client (MlViewAppContext *a_this) ;

struct MlViewAppSettings * mlview_app_context_get_settings (MlViewAppContext *a_this) ;


MlViewFileSelection * mlview_app_context_get_file_selector (MlViewAppContext * a_this,
                                                            const gchar * a_title);

void mlview_app_context_set_window_transient_for_app (MlViewAppContext * a_this,
                                                      GtkWindow * a_window);

gint mlview_app_context_get_xpm (MlViewAppContext * a_this,
                                 const gchar * a_xpm_name,
                                 GdkPixmap ** a_pixmap,
                                 GdkBitmap ** a_bitmap);

void mlview_app_context_set_xml_catalog (MlViewAppContext * a_this,
                                         xmlCatalog * a_xml_catalog);

xmlCatalog *mlview_app_context_get_xml_catalog (MlViewAppContext* a_this);

G_END_DECLS
#endif /*__MLVIEW-APP-CONTEXT_H__*/
